==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/PropertyContext.h <==
// class gnu.java.beans.decoder.PropertyContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class ea23baef93420b4f gnu_java_beans_decoder_AbstractObjectContext
// @dep_class 77b5fde7019ba4fd gnu_java_beans_decoder_PropertyContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractObjectContext

#include "gnu/java/beans/decoder/AbstractObjectContext.h"

#ifndef _JC_gnu_java_beans_decoder_PropertyContext_H_
#define _JC_gnu_java_beans_decoder_PropertyContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PropertyContext$sub_refs	_jc_gnu_java_beans_decoder_PropertyContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PropertyContext$sub_nonrefs	_jc_gnu_java_beans_decoder_PropertyContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PropertyContext$refs	_jc_gnu_java_beans_decoder_PropertyContext$refs;
typedef struct _jc_gnu_java_beans_decoder_PropertyContext$nonrefs	_jc_gnu_java_beans_decoder_PropertyContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PropertyContext$object	_jc_gnu_java_beans_decoder_PropertyContext$object;

typedef const struct _jc_gnu_java_beans_decoder_PropertyContext$vmethods	_jc_gnu_java_beans_decoder_PropertyContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PropertyContext$vtable	_jc_gnu_java_beans_decoder_PropertyContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PropertyContext$vtype	_jc_gnu_java_beans_decoder_PropertyContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PropertyContext$method$_init$a34354cd9552963f(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_gnu_java_beans_decoder_PropertyContext$method$addParameterObject$4706d521eeccfb00(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_PropertyContext$method$endContext$404ed46ecd22657f(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_object *);
extern void _jc_gnu_java_beans_decoder_PropertyContext$method$notifyStatement$516a25c30df0911b(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_object *);
extern jboolean _jc_gnu_java_beans_decoder_PropertyContext$method$subContextFailed$dac667c9783c2a33(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *);
extern void _jc_gnu_java_beans_decoder_PropertyContext$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PropertyContext$method_info$addParameterObject$4706d521eeccfb00;
extern _jc_method _jc_gnu_java_beans_decoder_PropertyContext$method_info$endContext$404ed46ecd22657f;
extern _jc_method _jc_gnu_java_beans_decoder_PropertyContext$method_info$notifyStatement$516a25c30df0911b;
extern _jc_method _jc_gnu_java_beans_decoder_PropertyContext$method_info$subContextFailed$dac667c9783c2a33;
extern _jc_method _jc_gnu_java_beans_decoder_PropertyContext$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PropertyContext$vmethods {
	void	(*addParameterObject$4706d521eeccfb00)(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*endContext$404ed46ecd22657f)(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_object *);
	void	(*notifyStatement$516a25c30df0911b)(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_object *);
	jboolean	(*subContextFailed$dac667c9783c2a33)(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_PropertyContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	gnu_java_beans_decoder_AbstractObjectContext;
	_jc_gnu_java_beans_decoder_PropertyContext$vmethods	gnu_java_beans_decoder_PropertyContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PropertyContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PropertyContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PropertyContext$sub_refs {
	struct _jc_java_lang_Object$object	*argument;
	struct _jc_java_lang_String$object	*propertyName;
	struct _jc_java_lang_String$object	*prefix;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PropertyContext$refs {
    _jc_gnu_java_beans_decoder_PropertyContext$sub_refs	gnu_java_beans_decoder_PropertyContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PropertyContext$sub_nonrefs {
	jboolean	methodCalled;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PropertyContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_PropertyContext$sub_nonrefs	gnu_java_beans_decoder_PropertyContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PropertyContext$object {
	_jc_gnu_java_beans_decoder_PropertyContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PropertyContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PropertyContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PropertyContext$vtype _jc_gnu_java_beans_decoder_PropertyContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PropertyContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PropertyContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PropertyContext_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/PropertyContext.h <==
// class gnu.java.beans.decoder.PropertyContext

// class file dependencies
// @dep_class f38552320b706ae7 gnu_java_beans_decoder_AbstractContext
// @dep_class ea23baef93420b4f gnu_java_beans_decoder_AbstractObjectContext
// @dep_class 77b5fde7019ba4fd gnu_java_beans_decoder_PropertyContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractObjectContext

#include "gnu/java/beans/decoder/AbstractObjectContext.h"

#ifndef _JC_gnu_java_beans_decoder_PropertyContext_H_
#define _JC_gnu_java_beans_decoder_PropertyContext_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PropertyContext$sub_refs	_jc_gnu_java_beans_decoder_PropertyContext$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PropertyContext$sub_nonrefs	_jc_gnu_java_beans_decoder_PropertyContext$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PropertyContext$refs	_jc_gnu_java_beans_decoder_PropertyContext$refs;
typedef struct _jc_gnu_java_beans_decoder_PropertyContext$nonrefs	_jc_gnu_java_beans_decoder_PropertyContext$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PropertyContext$object	_jc_gnu_java_beans_decoder_PropertyContext$object;

typedef const struct _jc_gnu_java_beans_decoder_PropertyContext$vmethods	_jc_gnu_java_beans_decoder_PropertyContext$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PropertyContext$vtable	_jc_gnu_java_beans_decoder_PropertyContext$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PropertyContext$vtype	_jc_gnu_java_beans_decoder_PropertyContext$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PropertyContext$method$_init$a34354cd9552963f(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_beans_decoder_PropertyContext$method$addParameterObject$4706d521eeccfb00(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_PropertyContext$method$endContext$404ed46ecd22657f(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_PropertyContext$method$notifyStatement$516a25c30df0911b(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_beans_decoder_PropertyContext$method$subContextFailed$dac667c9783c2a33(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_beans_decoder_PropertyContext$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PropertyContext$method_info$addParameterObject$4706d521eeccfb00;
extern _jc_method _jc_gnu_java_beans_decoder_PropertyContext$method_info$endContext$404ed46ecd22657f;
extern _jc_method _jc_gnu_java_beans_decoder_PropertyContext$method_info$notifyStatement$516a25c30df0911b;
extern _jc_method _jc_gnu_java_beans_decoder_PropertyContext$method_info$subContextFailed$dac667c9783c2a33;
extern _jc_method _jc_gnu_java_beans_decoder_PropertyContext$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PropertyContext$vmethods {
	void	(*addParameterObject$4706d521eeccfb00)(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*endContext$404ed46ecd22657f)(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*notifyStatement$516a25c30df0911b)(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*subContextFailed$dac667c9783c2a33)(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_beans_decoder_PropertyContext$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_PropertyContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractContext$vmethods	gnu_java_beans_decoder_AbstractContext;
	_jc_gnu_java_beans_decoder_AbstractObjectContext$vmethods	gnu_java_beans_decoder_AbstractObjectContext;
	_jc_gnu_java_beans_decoder_PropertyContext$vmethods	gnu_java_beans_decoder_PropertyContext;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PropertyContext$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PropertyContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PropertyContext$sub_refs {
	struct _jc_java_lang_Object$object	*argument;
	struct _jc_java_lang_String$object	*propertyName;
	struct _jc_java_lang_String$object	*prefix;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PropertyContext$refs {
    _jc_gnu_java_beans_decoder_PropertyContext$sub_refs	gnu_java_beans_decoder_PropertyContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_refs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_refs	gnu_java_beans_decoder_AbstractContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PropertyContext$sub_nonrefs {
	jboolean	methodCalled;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PropertyContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractContext$sub_nonrefs	gnu_java_beans_decoder_AbstractContext;
    _jc_gnu_java_beans_decoder_AbstractObjectContext$sub_nonrefs	gnu_java_beans_decoder_AbstractObjectContext;
    _jc_gnu_java_beans_decoder_PropertyContext$sub_nonrefs	gnu_java_beans_decoder_PropertyContext;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PropertyContext$object {
	_jc_gnu_java_beans_decoder_PropertyContext$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PropertyContext$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PropertyContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PropertyContext$vtype _jc_gnu_java_beans_decoder_PropertyContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PropertyContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PropertyContext$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PropertyContext_H_ */
